YandexDictionaryException class sealed

An YandexDictionaryException is thrown if an error occurs while sending the request.

Implemented types
Implementers

Properties

error Object?
The error which was caught.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited